# BuildAnalysisResponseError

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**base_image_analysis** | [**BuildAnalysisResponseErrorBaseImageAnalysis**](BuildAnalysisResponseErrorBaseImageAnalysis.md) |  |
**build_log_analysis** | [**BuildAnalysisResponseErrorBuildLogAnalysis**](BuildAnalysisResponseErrorBuildLogAnalysis.md) |  |
**output_image_analysis** | [**BuildAnalysisResponseErrorBuildLogAnalysis**](BuildAnalysisResponseErrorBuildLogAnalysis.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

